@@ -14,11 +14,11 @@
     xportr.label_verbose = "none",
     xportr.length_verbose = "none",
     xportr.type_verbose = "none",
-    xportr.character_types = c("character", "Char"),
+    xportr.character_types = c("character", "char", "text", "date", "posixct", "posixt"),
     xportr.order_name = "order"
   )
   toset <- !(names(op.devtools) %in% names(op))
   if (any(toset)) options(op.devtools[toset])
   
   invisible()
-}
\ No newline at end of file
+}
