@@ -48,3 +48,19 @@ test_that("Error message given if file name is greater than 8 characters",{
   
 
 })
+
+test_that("Format message given if unexpected formats", {
+  tmpdir <- tempdir()
+  tmp <- file.path(tmpdir, "xyz.xpt")
+  
+  on.exit(unlink(tmpdir))
+  
+  df <- data.frame(USUBJID = c("1001", "1002", "10003"),
+                   AGE = c("M", "F", "M"),
+                   BIRTHDT = as.Date(c("2001-01-01", "1997-11-11", "1995-12-12"), "%Y-%m-%d"))
+  
+  # Forget the period in date9.
+  attr(df$BIRTHDT, "format.sas") <- "date9"
+  
+  expect_error(xportr_write(df, tmp))
+})
